
PredixPy
========

The Predix Python SDK has been crafted to help Python developers have quick
success writing applications using Predix Services.

Install it from PyPI::

    pip install predix

If that isn't working for you, we highly recommend `The Hitchiker's Guide to
Properly Installing Python`_ to learn about installing ``python``,
``pip``, and ``virtualenv`` for your environment.  For industrial environments, you
may also need to learn how to set your proxies.

.. _The Hitchiker's Guide to Properly Installing Python: http://docs.python-guide.org/en/latest/starting/installation/

See the `Predix Volcano App`_ for a full demonstration of the SDK
used in a Python Flask App.

.. _Predix Volcano App: https://github.com/PredixDev/predix-volcano-app

Getting Started
---------------

Please see the `Getting Started Guide`_ for a walkthrough and introduction to
basic usage of the Python SDK.

.. _Getting Started Guide: https://predixpy.run.aws-usw02-pr.ice.predix.io/getting-started/index.html

- [x] `User Account and Authentication`_ (UAA)
- [x] `Predix Asset`_
- [x] `Predix Time Series`_
- [x] `Predix Access Control`_ (ACS)
- [x] `Predix Blob Store`_
- [x] `Predix Cache`_ (Redis)
- [x] `Predix Database as a Service`_ (PostgreSQL)
- [x] `Predix Event Hub`_
- [x] `Logging`_
- more...

.. _User Account and Authentication: https://predixpy.run.aws-usw02-pr.ice.predix.io/services/index.html#user-accounts-and-authentication
.. _Predix Asset: https://predixpy.run.aws-usw02-pr.ice.predix.io/services/index.html#asset
.. _Predix Time Series: https://predixpy.run.aws-usw02-pr.ice.predix.io/services/index.html#time-series
.. _Predix Access Control: https://predixpy.run.aws-usw02-pr.ice.predix.io/services/index.html#access-control
.. _Predix Blob Store: https://predixpy.run.aws-usw02-pr.ice.predix.io/services/index.html#blob-store
.. _Predix Cache: https://predixpy.run.aws-usw02-pr.ice.predix.io/services/index.html#predix-cache
.. _Predix Database as a Service: https://predixpy.run.aws-usw02-pr.ice.predix.io/services/index.html#predix-dbaas
.. _Predix Event Hub: https://predixpy.run.aws-usw02-pr.ice.predix.io/services/index.html#event-hub
.. _Logging: https://predixpy.run.aws-usw02-pr.ice.predix.io/services/index.html#logging

Getting Help
------------

If something doesn't work as expected and you want help:

- Create a `GitHub Issue`_ in this project
- Ask on the `Predix Developer Forum`_
- Send email to volcano@ge.com and we'll respond as soon as we can

.. _GitHub Issue: https://github.com/PredixDev/predixpy/issues
.. _Predix Developer Forum: https://forum.predix.io/index.html

Contributors
------------

See the `Developing PredixPy Guide`_ if you want to contribute or
modify the SDK itself.

If you send a PR it will be reviewed as soon as possible but contribution
guidelines and agreements for external parties have not been finalized.

.. _Developing PredixPy Guide: https://predixpy.run.aws-usw02-pr.ice.predix.io/devguide/index.html

.. image:: https://ga-beacon.appspot.com/UA-82773213-1/predixpy/readme?pixel
   :target: https://github.com/PredixDev/predixpy

